@@ -23,10 +23,11 @@ This extension either adds nodes to a path so that
   into a given number of equal segments.
 
 """
-import math
-import inkex
 
-from inkex import bezier, PathElement, CubicSuperPath
+import math
+
+import inkex
+from inkex import bezier,  PathElement, CubicSuperPath
 
 
 class AddNodes(inkex.EffectExtension):
@@ -39,7 +40,7 @@ class AddNodes(inkex.EffectExtension):
         pars.add_argument("--method", help="The kind of division to perform")
 
     def effect(self):
-        for node in self.svg.selection.filter(PathElement).values():
+        for node in self.svg.get_selected(PathElement):
             new = []
             for sub in node.path.to_superpath():
                 new.append([sub[0][:]])
